==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEvaluationPlansAuditor.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlansAuditor] (
	@Instance VARCHAR(50) = NULL,
	@UserId VARCHAR(50) = NULL,
	@Campaigns VARCHAR(MAX) = NULL,
	@EndDate VARCHAR(50) = NULL,
	@EvaluationPlans VARCHAR(MAX) = NULL,
	@EvaluationFormats VARCHAR(MAX) = NULL,
	@Modalities VARCHAR(MAX) = NULL,
	-- @EvaluationTypes VARCHAR(50) = NULL,
	@Completed BIT = NULL,
	@UserFunction VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_2 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM_2 VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER_2 VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA_2 VARCHAR(MAX) = ''

	-- ARMAMOS EL SELECT DE LA QURY
	SET @SQL_SELECT_1 += '
		SELECT EP.[ID]																								''id'', 
				EP.[Description]																					''description'',
				EP.[Modality]																						''modality'',
				EP.[DateFin]																						''dateFin'',      
				EP.[CreatedDate]																					''createdDate'',      
				EP.[IdEvaluationFormat]																				''idEvaluationFormat'',
				COUNT(DISTINCT AEP.[IdInteraction])																	''totalInteraction'',
				COUNT(DISTINCT CASE AEP.[Completed] WHEN 1 THEN AEP.[IdInteraction] ELSE NULL END)					''completedInteraction'',      
				COUNT(DISTINCT CASE AEP.[Status] WHEN 0 THEN AEP.[IdInteraction] ELSE NULL END)						''discardedInteraction'',
				-- COUNT(DISTINCT CASE AEP.[Completed] WHEN 0 THEN AEP.[IdInteraction] ELSE NULL END)				''pendingInteraction'',
				COUNT(DISTINCT
					CASE 
					WHEN AEP.[Completed] = 0 AND AEP.[Status] = 1 THEN AEP.[IdInteraction] 
					ELSE NULL 
					END)																							''pendingInteraction'',
				SUM(DISTINCT CASE AEP.[Completed] WHEN 0 THEN AEP.[InteractionDuration] ELSE 0 END)					''pendingInteractionTime'',
				COUNT(AEP.[IdInteraction])																			''totalEvaluation'',    
				COUNT(CASE AEP.[Completed] WHEN 1 THEN 1 ELSE NULL END)												''completedEvaluation'',      
				COUNT(CASE AEP.[Status] WHEN 0 THEN 1 ELSE NULL END)												''discardedEvaluation'',    
				-- COUNT(CASE AEP.[Completed] WHEN 0 THEN 1 ELSE NULL END)											''pendingEvaluation'',
				COUNT(
					CASE 
					WHEN AEP.[Completed] = 0 AND AEP.[Status] = 1 THEN 1 
					ELSE NULL 
					END)																							''pendingEvaluation'',
				SUM(CASE AEP.[Completed] WHEN 0 THEN AEP.[InteractionDuration] ELSE 0 END)							''pendingEvaluationTime'' '

	SET @SQL_FROM += '
			FROM [EvaluationPlan] EP (NOLOCK)
			INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
				ON (AEP.[Instance] = EP.[Instance] 
					AND AEP.[IdEvaluationPlan] = EP.[ID]'

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @UserFunction = 'auditor'
	BEGIN
		SET @SQL_FROM += '
					AND AEP.[IdAuditor] = ''' + @UserId + ''') '
	END
	ELSE IF (@UserFunction = 'admin')
	BEGIN
		SET @SQL_FROM += ')'
	END
	ELSE 
	BEGIN
		SET @SQL_FROM += '
					AND AEP.[IdAuditor] = ''' + @UserId + ''') '
	END 

	SET @SQL_FILTER += '
			WHERE EP.[Instance] = ''' + @Instance + '''
				AND EP.[DateFin] <= ''' + @EndDate + ''' 
				AND EP.[Enabled] = 1 
				AND (
					(
						EP.[Evaluation_Mode] = ''X'' 
						AND 
						(
							EP.[Status] = 7
							OR
							EP.[Status] = 8
						)
					)
					OR
					(EP.[Evaluation_Mode] = ''M'')
				) '

	IF (@Campaigns IS NOT NULL AND @Campaigns <> '')
	BEGIN
		SET @SQL_FILTER += '
				AND EP.[IdEvaluationFormat] IN (
					SELECT CEF.[IdEvaluationFormat] FROM CampaignEvaluationFormat CEF 
						WHERE CEF.[Instance] = ''' + @Instance + '''
							AND CEF.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','',''))) '
	END

	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans <> '') SET @SQL_FILTER += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@EvaluationFormats IS NOT NULL AND @EvaluationFormats <> '') SET @SQL_FILTER += 'AND EP.[IdEvaluationFormat] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationFormats + ''','','')) '
	IF (@Modalities IS NOT NULL AND @Modalities <> '') SET @SQL_FILTER += 'AND EP.[Modality] IN (SELECT Value FROM [dbo].[split](''' + @Modalities + ''','','')) '
	-- IF @EvaluationTypes IS NOT NULL AND @EvaluationTypes <> '' SET @SQL_FILTER += 'AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','','')) '
	
	-- VARIABLE PARA FILTRAR SOLO LOS REGISTROS DE AUDITOREVALUATIONPLAN CON [COMPLETED] = 1
	IF (@Completed = 1)
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 1 '
		SET @SQL_FILTER_2 = ' '
	END
	ELSE 
	BEGIN
		-- SI NO LLEGA UN VALOR PARA EVALUATION PLANS, BUSCAMOS SOLO LOS QUE TIENEN INTERACCIONES PENDIENTES
		IF (@EvaluationPlans IS NULL OR @EvaluationPlans = '')
		BEGIN
			--SET @SQL_FILTER += 'AND AEP.[Completed] = 0 '
			SET @SQL_FILTER_2 = 'WHERE X.[pendingInteraction] > 0 '
		END
	END
	

	SET @SQL_EXTRA += '
			GROUP BY EP.[ID],
						EP.[Modality],
						EP.[DateFin],
						EP.[CreatedDate],
						EP.[IdEvaluationFormat],
						EP.[Description]'

	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	--SET @SQL_SELECT_1 = 'SELECT * FROM (' + @SQL_SELECT_1 + ') AS X WHERE X.[pendingInteractionCount] > 0 ORDER BY X.[Description] ASC; '
	SET @SQL_SELECT_2 = 'SELECT * '
	SET @SQL_FROM_2 = 'FROM (' + @SQL_SELECT_1 + ') AS X '
	-- @SQL_FILTER_2 YA FUE DEFINIDO SEGUN SE BUSCAN LAS YA EVALUADAS O NO EVALUADAS
	SET @SQL_EXTRA_2 = 'ORDER BY X.[Description] ASC'

	SET @SQL_SELECT_2 += @SQL_FROM_2 + @SQL_FILTER_2 + @SQL_EXTRA_2

	-- select @SQL_SELECT_2;
	EXEC (@SQL_SELECT_2)
	
	SET NOCOUNT OFF
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.8.2_database.tar.gz: database/mssql/procedures/GetEvaluationPlansAuditor.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationPlansAuditor] (
	@Instance VARCHAR(50) = NULL,
	@UserId VARCHAR(50) = NULL,
	@Campaigns VARCHAR(MAX) = NULL,
	@EndDate VARCHAR(50) = NULL,
	@EvaluationPlans VARCHAR(MAX) = NULL,
	@EvaluationFormats VARCHAR(MAX) = NULL,
	@Modalities VARCHAR(MAX) = NULL,
	-- @EvaluationTypes VARCHAR(50) = NULL,
	@Completed BIT = NULL,
	@UserFunction VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_2 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM_2 VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER_2 VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA_2 VARCHAR(MAX) = ''

	-- ARMAMOS EL SELECT DE LA QURY
	SET @SQL_SELECT_1 += '
		SELECT EP.[ID]																								''id'', 
				EP.[Description]																					''description'',
				EP.[Status]																							''status'',
				EP.[Percentage]																						''Percentage'',
				EP.[Modality]																						''modality'',
				EP.[DateFin]																						''dateFin'',      
				EP.[CreatedDate]																					''createdDate'',      
				EP.[IdEvaluationFormat]																				''idEvaluationFormat'',
				COUNT(DISTINCT AEP.[IdInteraction])																	''totalInteraction'',
				COUNT(DISTINCT CASE AEP.[Completed] WHEN 1 THEN AEP.[IdInteraction] ELSE NULL END)					''completedInteraction'',      
				COUNT(DISTINCT CASE AEP.[Status] WHEN 0 THEN AEP.[IdInteraction] ELSE NULL END)						''discardedInteraction'',
				-- COUNT(DISTINCT CASE AEP.[Completed] WHEN 0 THEN AEP.[IdInteraction] ELSE NULL END)				''pendingInteraction'',
				COUNT(DISTINCT
					CASE 
					WHEN AEP.[Completed] = 0 AND AEP.[Status] = 1 THEN AEP.[IdInteraction] 
					ELSE NULL 
					END)																							''pendingInteraction'',
				SUM(DISTINCT CASE AEP.[Completed] WHEN 0 THEN AEP.[InteractionDuration] ELSE 0 END)					''pendingInteractionTime'',
				COUNT(AEP.[IdInteraction])																			''totalEvaluation'',    
				COUNT(CASE AEP.[Completed] WHEN 1 THEN 1 ELSE NULL END)												''completedEvaluation'',      
				COUNT(CASE AEP.[Status] WHEN 0 THEN 1 ELSE NULL END)												''discardedEvaluation'',    
				-- COUNT(CASE AEP.[Completed] WHEN 0 THEN 1 ELSE NULL END)											''pendingEvaluation'',
				COUNT(
					CASE 
					WHEN AEP.[Completed] = 0 AND AEP.[Status] = 1 THEN 1 
					ELSE NULL 
					END)																							''pendingEvaluation'',
				SUM(CASE AEP.[Completed] WHEN 0 THEN AEP.[InteractionDuration] ELSE 0 END)							''pendingEvaluationTime'' '

	SET @SQL_FROM += '
			FROM [EvaluationPlan] EP (NOLOCK)
			INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
				ON (AEP.[Instance] = EP.[Instance] 
					AND AEP.[IdEvaluationPlan] = EP.[ID]'

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @UserFunction = 'auditor'
	BEGIN
		SET @SQL_FROM += '
					AND AEP.[IdAuditor] = ''' + @UserId + ''') '
	END
	ELSE IF (@UserFunction = 'admin')
	BEGIN
		SET @SQL_FROM += ')'
	END
	ELSE 
	BEGIN
		SET @SQL_FROM += '
					AND AEP.[IdAuditor] = ''' + @UserId + ''') '
	END 

	SET @SQL_FILTER += '
			WHERE EP.[Instance] = ''' + @Instance + '''
				AND EP.[DateFin] <= ''' + @EndDate + ''' 
				AND EP.[Enabled] = 1 
				AND (
					(
						EP.[Evaluation_Mode] = ''X'' 
						AND 
						(
							EP.[Status] = 7
							OR
							EP.[Status] = 8
						)
					)
					OR
					(EP.[Evaluation_Mode] = ''M'')
				) '

	IF (@Campaigns IS NOT NULL AND @Campaigns <> '')
	BEGIN
		SET @SQL_FILTER += '
				AND EP.[IdEvaluationFormat] IN (
					SELECT CEF.[IdEvaluationFormat] FROM CampaignEvaluationFormat CEF 
						WHERE CEF.[Instance] = ''' + @Instance + '''
							AND CEF.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','',''))) '
	END

	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans <> '') SET @SQL_FILTER += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@EvaluationFormats IS NOT NULL AND @EvaluationFormats <> '') SET @SQL_FILTER += 'AND EP.[IdEvaluationFormat] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationFormats + ''','','')) '
	IF (@Modalities IS NOT NULL AND @Modalities <> '') SET @SQL_FILTER += 'AND EP.[Modality] IN (SELECT Value FROM [dbo].[split](''' + @Modalities + ''','','')) '
	-- IF @EvaluationTypes IS NOT NULL AND @EvaluationTypes <> '' SET @SQL_FILTER += 'AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','','')) '
	
	-- VARIABLE PARA FILTRAR SOLO LOS REGISTROS DE AUDITOREVALUATIONPLAN CON [COMPLETED] = 1
	IF (@Completed = 1)
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 1 '
		SET @SQL_FILTER_2 = ' '
	END
	ELSE 
	BEGIN
		-- SI NO LLEGA UN VALOR PARA EVALUATION PLANS, BUSCAMOS SOLO LOS QUE TIENEN INTERACCIONES PENDIENTES
		IF (@EvaluationPlans IS NULL OR @EvaluationPlans = '')
		BEGIN
			--SET @SQL_FILTER += 'AND AEP.[Completed] = 0 '
			SET @SQL_FILTER_2 = 'WHERE X.[pendingInteraction] > 0  AND X.[percentage] is null '
		END
	END
	

	SET @SQL_EXTRA += '
			GROUP BY EP.[ID],
						EP.[Modality],
						EP.[DateFin],
						EP.[CreatedDate],
						EP.[IdEvaluationFormat],
						EP.[Status],
						EP.[Description],
						EP.[Percentage]'

	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA

	--SET @SQL_SELECT_1 = 'SELECT * FROM (' + @SQL_SELECT_1 + ') AS X WHERE X.[pendingInteractionCount] > 0 ORDER BY X.[Description] ASC; '
	SET @SQL_SELECT_2 = 'SELECT * '
	SET @SQL_FROM_2 = 'FROM (' + @SQL_SELECT_1 + ') AS X '
	-- @SQL_FILTER_2 YA FUE DEFINIDO SEGUN SE BUSCAN LAS YA EVALUADAS O NO EVALUADAS
	SET @SQL_EXTRA_2 = 'ORDER BY X.[Description] ASC'

	SET @SQL_SELECT_2 += @SQL_FROM_2 + @SQL_FILTER_2 + @SQL_EXTRA_2

	-- select @SQL_SELECT_2;
	EXEC (@SQL_SELECT_2)
	
	SET NOCOUNT OFF
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
